@@ -150,13 +150,17 @@ class ByBit:
                 rest_api=self.rest
             )
         self.private_feed = None
-        if subscribe_to_private_feed:
+        if subscribe_to_private_feed and self.credentials is not None:
             self.private_feed = ByBitStream(self.credentials, private=True, background=True, rest_api=self.rest)
 
     def get_positions(self, symbol: Optional[str] = None, **kwargs) -> List[dict]:
         if self.private_feed is not None:
             positions = self.private_feed.position_handler.positions
-            return [positions.get(symbol)] if symbol is not None else list(positions.values())
+            if symbol is not None:
+                symbol_position = positions.get(symbol)
+                return [] if symbol_position is None else [symbol_position]
+            else:
+                list(positions.values())
         return self.rest.get_positions(symbol, **kwargs)
 
     def get_orderbook(self, symbol: str, depth: Optional[int] = None) -> dict:
@@ -460,6 +464,10 @@ class ByBitRest:
         # self.throttler = ByBitThrottler()
         self._session = Session()
         self._base_url = base_url
+        if api_key is None:
+            api_key = ''
+        if api_secret is None:
+            api_secret = ''
         self._api_key = api_key
         self._api_secret = api_secret
         self._recv_window = str(5000)
